
void ISR_ZeroSec() {
  IntFlag = true;            // indirectly calls ZeroSec();
}


void ISR_DS_move() {
  DstBumpIntFlag = true;     // indirectly calls DS_bump ();
}


void DS_bump () {
  // called when the DS pushbutton is pressed
  // either adds or subtracts one hour, when going into daylight saving add, when leaving daylight saving subtract
  //   examine the ds_direction switch [toSummer | to Winter] to determine if entering or leaving
  
  static unsigned long last_interrupt_time = 0;
  unsigned long interrupt_time = millis();
  
  // If interrupts come faster than 300ms, assume it's a bounce and ignore
  if (interrupt_time - last_interrupt_time > 300) {
  
    time_t grab;                              // format of this is seconds since 1970
    RTC.get();                                // this makes sure system time (now()) is synced to RTC module
    grab = now();                             // to update tmElements_t, ie hour() etc
    if (digitalRead(ds_adjust) == HIGH) {
      grab += 3600;
      }
    else {  // (digitalRead(ds_adjust == LOW)
      grab -= 3600;
    }
   
    setTime (grab);                           // sets the system time
    RTC.set (grab);                           // write (updated) system time back to RTC
  }
  last_interrupt_time = interrupt_time;       // for debounce
}


void ZeroSec(void) {
  // idea is to use a pushbutton to bump time to exact hour when radio hour beeps heard
  //   to stop 'random' button pushes is limited to 5 mins before and after hour mark
  //   called via an interrupt
  // no need to debounce as it can run multiple times with no consequence
  // the DS3231 module is accurate to 2 ppm, ~ 1 min per year
  
  time_t grab; // format of this is seconds since 1970

  RTC.get();   // this makes sure system time (now()) is synced to RTC module
    
  grab = now();   // to update tmElements_t, ie hour() etc
  
  if ((minute() <= 5) || (minute() >= 55)) {    // bump time to top of hour
  
    if (minute() <= 5) setTime (hour(), 0, 0, day(), month(), year());      // slide time back a bit
    if (minute() >= 55) setTime (hour()+1, 0, 0, day(), month(), year());   // slide time forward a bit
  
    grab = now();   // retreives the now bump updated system time in time_t format
    RTC.set(grab);  // write (updated) system time back to RTC
  
    show_time ();       //for immediate update as indication to user it happened
    reset_display (); 
  }
}

