void setup () {

  pinMode (BumpINTpin, INPUT_PULLUP);
  pinMode (DstINTpin, INPUT_PULLUP);
  pinMode (ds_adjust, INPUT_PULLUP);

  setSyncProvider(RTC.get);
  setSyncInterval(300);      // seconds between sync
  
  attachInterrupt (digitalPinToInterrupt(BumpINTpin), ISR_ZeroSec, FALLING);
  attachInterrupt (digitalPinToInterrupt(DstINTpin), ISR_DS_move, FALLING);
  
  interrupts ();                              // enables them

  dht.begin();
  leds.begin();
  leds.show();    //initialises all to off

  u8g.setColorIndex(1);         // pixel on, because u8g.getMode() == U8G_MODE_BW (= 1)
  u8g.setFont(u8g_font_unifont);

  #if (DEBUG)
    Serial.begin(115200);
    while (!Serial) {      // wait
    }
    Serial << "Serial open ... " << endl << endl;

    #if (KBSetTime)
      SetTimeFromKB ();
    #else
      ShowSysTimestatus ();
    #endif
  #endif
}


//------------------------------------------------------------------------------------------
void ShowSysTimestatus () {
  
  Serial << endl << endl << "---------------------------------------------------------" << endl;
  Serial << "System time timeSync status is " << timeStatus();
    switch (timeStatus()) {
      case 0: Serial << ", timeNotSet."; break;
      case 1: Serial << ", timeNeedsSync."; break;
      case 2: Serial << ", timeSet."; break;
    }
  Serial << endl;
  Serial << "System time is currently: "<< day() << "/" << month() << "/" << year();
  Serial << "    " << hour() << ":" << minute() << ":" << second() << endl;
  Serial << "Daylight saving is " << (digitalRead(ds_adjust)? "OFF AEST = Aust Eastern Standard time" : "ON AEDT = Aust Eastern Daylight time") << endl;
  Serial << "------------------" << endl;

  Serial << "Hrs_str = " << hrs_str << endl;
  Serial << "Mins_str = " << mins_str << endl;
  Serial << "Time_str = " << time_str << endl;
  Serial << "myDay_str = " << day_str << endl;
    
  Serial << "sys dayStr = " << dayStr(weekday()) << endl;
  Serial << "sys dayShortStr = " << dayShortStr(weekday()) << endl;
  Serial << "myMnth_str = " << mnth_str << endl;
  Serial << "sys monthStr = " << monthStr(month()) << endl;
  Serial << "sys monthShortStr = " << monthShortStr(month()) << endl;
    
  Serial << "Year_str = " << yr_str << endl;
  Serial << "Date_str = " << date_str << endl;
  Serial << "Temp_str = " << temp_str << endl;
  Serial << "Hum_str = " << hum_str << endl;
  Serial << "DST = " << !digitalRead(ds_adjust) << endl;
    
}

//------------------------------------------------------------------------------------------
void SetTimeFromKB () {
  // idea is to provide a mechanism to set the time to the RTC module from the keyboard

  time_t KBentry;
  int y, m, d, h, n, s;
  bool prompt = true;

  //check for input to set the RTC, minimum length is 19, i.e. yyyy,mm,dd,hh,mm,ss
  if (prompt) {
    Serial << "Ensure daylight saving switch is set to the correct current state and then" << endl;
    Serial << "  enter time setting in form yyyy,mm,dd,hh,mm,ss" << endl;
    Serial << "Use leading zeros as required eg. 1978,06,18,20,07,30" << endl << endl;
    prompt = false;
  }

  while (true) {            // wait, want to stick here until time entered
    if (Serial.available() >= 19) {
      y = Serial.parseInt();
      m = Serial.parseInt();
      d = Serial.parseInt();
      h = Serial.parseInt();
      n = Serial.parseInt();
      s = Serial.parseInt();
      break;                      // user has entered time
    }
  }

  setTime (h, n, s, d, m, y);  // puts into system time, which is what now() reads

  KBentry = now();   // retreives the now() puts it into time_t format
  RTC.set(KBentry);  // write (updated) system time back to RTC module

  Serial << "You have set the clock with the following parameters:" << endl;
  Serial <<"hr = " << h << ", min = " << n << ", sec = " << s <<", day = " << d << ", mth = "<< m << ", yr = " << y << endl;
  Serial << "Daylight saving is " << (!digitalRead(ds_adjust)? "ON" : "OFF") << endl << endl;
  
  Serial << "Do you wish to accept this seting y/n?" << endl;
  while (true) {                                                  // wait for answer
    if (Serial.available() > 0) {
      char ans = Serial.read ();                         // grab the first character
      if ((ans == 'n') || (ans == 'N')) softReset();     // sets up for another go at time entry
      if ((ans == 'y') || (ans == 'Y')) {
        Serial << "Time is set!" << endl;
        Serial << "Change #define KBSetTime and #define DEBUG both to false and download again for normal running." << endl;
        break;                                           // get out of here, allow program to run
      }
    }
  }
  //ShowSysTimestatus ();  
}        


void softReset (){
  // causes a watchdog fault and so the sketch restarts
  asm volatile ("  jmp 0");
}

